@@ -5,26 +5,27 @@
 
 from __future__ import print_function
 
+import io
 import sys
 from typing import Dict
 
 try:
-    import idf_size.core
+    import esp_idf_size.core
 except ImportError:
     sys.path.append('..')
-    import idf_size.core
+    import esp_idf_size.core
 
 
 if __name__ == '__main__':
     # Should deliver a RuntimeError as the 'test' header doesn't exist
     try:
-        idf_size.core.scan_to_header([], 'test')
+        esp_idf_size.core.scan_to_header([], 'test')
     except RuntimeError as e:
         assert "Didn't find line" in str(e)
 
     # Should deliver a RuntimeError as there's no content under the heading
     try:
-        idf_size.core.load_segments(['Memory Configuration'])
+        esp_idf_size.core.load_segments(io.StringIO('Memory Configuration'))
         pass
     except RuntimeError as e:
         assert 'End of file' in str(e)
@@ -33,4 +34,4 @@ if __name__ == '__main__':
                 'dram0_0_seg': {'origin': 0, 'length': 0}}
     sections = {}  # type: Dict
 
-    print(idf_size.core.get_summary('a.map', segments, sections, 'esp32'), end='')
+    print(esp_idf_size.core.get_summary('a.map', segments, sections, 'esp32'), end='')
